##  Start Transformations
The planning and preparation is finished now and you can fully focus on transforming the IT landscape. You have the following options to start the transformations:
  * In the fact sheet, go to the Transformations tab and execute the transformations there.
  * In the transformations explorer, you can execute multiple transformations at the same time.


![Review and execute transformations dialog with options to cancel or execute a rollout application](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioa66ac9917e7c42a3abb422606d0d4911_HiRes.png)
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
